@@ -281,7 +281,7 @@ class BatchPostingWindow(NextGenWindow):
             (str): The amount extracted.
         """
         # Find the amount with optional commas and dollar sign
-        match = re.search(r"-?\$-?\s?([\d,]+\.?\d*)", description)
+        match = re.search(r"-?\$\s?(-?[\d,]+\.?\d*)", description)
         if match:
             # Extract the numeric part and replace commas
             amount_str = match.group(1).replace(",", "")
