@@ -191,7 +191,8 @@ class ImportFileWindow(NextGenWindow):
                 with contextlib.suppress(_ctypes.COMError):
                     modal.child_window(title="OK", auto_id="2", control_type="Button").click()
 
-    @retry(tries=3, delay=1)
+    @capture_screenshot_if_exception()
+    @retry(exceptions=_ctypes.COMError, tries=5, delay=20, backoff=2)
     def _modal_exists(self, modal: WindowSpecification) -> bool:
         """Check if modal exists.
 
@@ -200,9 +201,7 @@ class ImportFileWindow(NextGenWindow):
         Returns:
             bool: True if modal exists, False otherwise
         """
-        if modal.exists(timeout=3, retry_interval=1):
-            return True
-        return False
+        return modal.exists()
 
     def convert_edi_files_to_excel(self, excel_file_path: str) -> None:
         """Converts EDI files to Excel format by interacting with the application's excel export functionality.
