@@ -8,6 +8,7 @@ from pathlib import Path
 import re
 from typing import Optional
 from typing import Any
+from retry import retry
 
 from decimal import Decimal
 from t_desktop.config import IS_WINDOWS_OS
@@ -31,6 +32,7 @@ from t_nextgen.exceptions import (
     Ins1FieldNotFoundException,
     Ins2FieldNotFoundException,
     Ins3FieldNotFoundException,
+    LnItemRsnsNotUpdatedException,
     PayFieldNotFoundException,
     ServiceLineMissingRequiredFieldError,
     TransactionNumberNotFoundError,
@@ -173,11 +175,12 @@ class PaymentEntryWindow(NextGenWindow):
         self.logger.debug(f"Number of rows in Payment Entry: {len(rows)}")
         return rows
 
+    @retry(LnItemRsnsNotUpdatedException, tries=3, delay=1)
     def insert_text_in_ln_item_rsns(self, text: str, row: ListItemWrapper) -> None:
         """This method inserts text in the Ln Item Rsns field.
 
         Args:
-            text (str): text to be inserted
+            text (str): text to be inserted. This text will have codes separated by commas (Ex:"PR2,CO45")
             row (ListItemWrapper): row to select. Will use the first row if not provided
         """
         self.logger.debug(f"Inserting text in Ln Item Rsns: {text}")
@@ -187,6 +190,13 @@ class PaymentEntryWindow(NextGenWindow):
 
         self.remove_selected_items_from_ln_combobox(row)
         self.set_text_in_specific_row(row, "Ln Item Rsns", text, is_combobox=True)
+        row = self._get_row_by_auto_id(row.automation_id())  # need to get the row with updated Ln Item Rsns
+        next_gen_codes = row.descendants(title="Ln Item Rsns", control_type="Edit")[0].get_value()
+        # next_gen_codes example :  'CO45  (Charges exceed fee arrangement); PR2  (Coinsurance amount)'
+        codes_inserted = text.split(",")
+        for code in codes_inserted:
+            if code.strip() not in next_gen_codes:
+                raise LnItemRsnsNotUpdatedException(f"Error trying to insert {text} in Ln Item Rsns field.")
         return row
 
     def remove_selected_items_from_status_combobox(self, row: ListItemWrapper) -> None:
@@ -632,10 +642,15 @@ class PaymentEntryWindow(NextGenWindow):
             self.desktop_app.set_text(container.child_window(title="_txtDataEntry_105", control_type="Edit"), text)
             send_keys("{ENTER}")
 
-    def click_close_nextgen_alerts(self) -> None:
-        """Click close button on NextGen Alerts."""
+    def click_close_nextgen_alerts(self, timeout: int = 5, retry_interval: float = 1) -> None:
+        """Click close button on NextGen Alerts.
+
+        Args:
+            timeout (int, optional): Time to wait for alert to appear. Defaults to 5.
+            retry_interval (float, optional): Time between retries when checking for alert. Defaults to 1.
+        """
         alert = self.desktop_app.dialog.child_window(title="NextGen Alerts", control_type="Window")
-        if alert.exists(timeout=5, retry_interval=1):
+        if alert.exists(timeout=timeout, retry_interval=retry_interval):
             self.logger.debug("Clicking close on NextGen Alerts")
             alert.set_focus()
             with contextlib.suppress(_ctypes.COMError):
@@ -720,6 +735,13 @@ class PaymentEntryWindow(NextGenWindow):
         with contextlib.suppress(_ctypes.COMError):
             pnl_small_tool.child_window(auto_id="_cmdSmallTool_03", control_type="Button").click_input()
 
+    def click_balance_control_icon(self) -> None:
+        """Click balance control icon in pyament entry window."""
+        self.logger.debug("Clicking balance control icon in Payment Entry Window.")
+        pnl_small_tool = self.window.child_window(title="pnlSmallTool", control_type="Text")
+        with contextlib.suppress(_ctypes.COMError):
+            pnl_small_tool.child_window(auto_id="_cmdSmallTool_04", control_type="Button").click_input()
+
     def select_payer_in_drop_down(self, payer: str) -> None:
         """This method selects the payer in the drop down.
 
@@ -962,3 +984,27 @@ class PaymentEntryWindow(NextGenWindow):
         date_value = date_input.get_value()
         self.logger.debug(f"Date field value found: {date_value}")
         return date_value
+
+    def get_enc_clm_edit_value(self) -> str:
+        """This method gets the value by element name in edit control type.
+
+        Args:
+            element_name (str): element name
+
+        Returns:
+            str: value
+        """
+        pane = self.desktop_app.dialog.child_window(auto_id="_cboInput_103", control_type="Pane")
+        combo_box = pane.child_window(control_type="ComboBox")
+        edit_control = combo_box.child_window(control_type="Edit", found_index=0)
+        enc_clm = edit_control.get_value()
+        return enc_clm
+
+    def get_resub_value(self) -> str:
+        """This method gets the value from the resub field.
+
+        Returns:
+            str: resub value
+        """
+        resub = self.desktop_app.dialog.child_window(title="_txtDataEntry_116", control_type="Edit").get_value()
+        return resub
